translate.services

Package translate :: Package services |
[hide private]
[frames] | no frames]

# Package services

source code

translate.services is part of the translate toolkit. It provides network services for interacting with the toolkit

Submodules | [hide private]
translate.services.lookupclient: Small example program for querying an XML-RPC lookup service translate.services.lookupservice: Server program to serve messages over XML-RPC translate.services.tmserver: A translation memory server using tmdb for storage, communicates with clients using JSON over HTTP.